@@ -164,15 +164,6 @@ pareto_frontier <- function(r5r_core,
   set_output_dir(r5r_core, output_dir)
   set_fare_cutoffs(r5r_core, fare_cutoffs)
 
-  # pareto frontiers cannot be computed on frequencies-based GTFS, because it uses McRaptor
-  if (!is.null(fare_structure) & r5r_core$hasFrequencies()) {
-    stop(
-      "Assertion on 'r5r_core' failed: None of the GTFS feeds used to create ",
-      "the transit network can contain a 'frequencies' table. Try using ",
-      "gtfstools::frequencies_to_stop_times() to create a suitable feed."
-    )
-  }
-
   # call r5r_core method and process result -------------------------------
 
   frontier <- r5r_core$paretoFrontier(
