@@ -2,12 +2,6 @@ context("transit_network_to_sf")
 
 testthat::skip_on_cran()
 
-
-# setup_r5
-path <- system.file("extdata/poa", package = "r5r")
-r5r_core <- setup_r5(data_path = path, verbose=FALSE, temp_dir = TRUE)
-
-
 # expected behavior
 test_that("transit_network_to_sf - expected behavior", {
 
@@ -23,4 +17,3 @@ test_that("transit_network_to_sf - expected errors", {
   testthat::expect_error( transit_network_to_sf('a') )
 })
 
-stop_r5(r5r_core)
